@@ -9,6 +9,9 @@
 #' @param npcs number of principal component loadings to add to samples
 #'   (default is number of samples)
 #' @inheritParams remove_missing_values
+#' @param label_percent_varex If true then PCs will be labelled by the percent
+#'   of variability they explain.
+#' @inheritParams create_tidy_omic
 #'
 #' @returns A \code{tomic} object with principal components added to samples.
 #'
@@ -21,10 +24,16 @@ add_pcs <- function(
     value_var = NULL,
     center_rows = TRUE,
     npcs = NULL,
-    missing_val_method = "drop_samples") {
+    missing_val_method = "drop_samples",
+    label_percent_varex = TRUE,
+    verbose = TRUE
+    ) {
+
   checkmate::assertClass(tomic, "tomic")
   checkmate::assertLogical(center_rows, len = 1)
   stopifnot(length(npcs) <= 1, class(npcs) %in% c("NULL", "numeric", "integer"))
+  checkmate::assertLogical(label_percent_varex, len = 1)
+  checkmate::assertLogical(verbose, len = 1)
 
   design <- tomic$design
   feature_pk <- design$feature_pk
@@ -35,7 +44,8 @@ add_pcs <- function(
   triple_omic <- tomic_to(tomic, "triple_omic") %>%
     remove_missing_values(
       value_var = value_var,
-      missing_val_method = missing_val_method
+      missing_val_method = missing_val_method,
+      verbose = verbose
     )
 
   cast_formula <- stats::as.formula(paste0(feature_pk, " ~ ", sample_pk))
@@ -44,9 +54,9 @@ add_pcs <- function(
     reshape2::acast(formula = cast_formula, value.var = value_var)
 
   if (is.null(npcs)) {
-    npcs <- ncol(omic_matrix)
+    npcs <- min(dim(omic_matrix))
   }
-  stopifnot(npcs <= ncol(omic_matrix))
+  stopifnot(npcs <= ncol(omic_matrix), npcs <= nrow(omic_matrix))
   npcs <- round(npcs)
 
   # center
@@ -59,14 +69,21 @@ add_pcs <- function(
 
   # add eigenvalues and fraction of variance explained as unstructured data
   varex_df <- tibble::tibble(
-    pc_number = seq_len(ncol(omic_matrix)),
+    pc_number = seq_len(length(mat_svd$d)),
     eigenvalue = mat_svd$d
   ) %>%
     dplyr::mutate(
-      fraction_varex = eigenvalue^2 / (sum(eigenvalue^2)),
-      pc_label = glue::glue("PC{pc_number} ({scales::percent_format(2)(fraction_varex)})")
+      fraction_varex = eigenvalue^2 / (sum(eigenvalue^2))
     )
 
+  if (label_percent_varex) {
+    varex_df <- varex_df %>%
+      dplyr::mutate(pc_label = glue::glue("PC{pc_number} ({scales::percent_format(2)(fraction_varex)})"))
+  } else {
+    varex_df <- varex_df %>%
+      dplyr::mutate(pc_label = glue::glue("PC{pc_number}"))
+  }
+
   # find the npcs leading principal components
   pcs <- mat_svd$v[, 1:npcs, drop = FALSE]
   # calculate percent variance explained by PC
@@ -116,6 +133,7 @@ add_pcs <- function(
 #'     then drop features}
 #'   \item{impute}{Impute missing values}
 #' }
+#' @inheritParams create_tidy_omic
 #'
 #' @returns A \code{tomic} object where missing values have been accounted
 #'   for.
@@ -127,12 +145,15 @@ add_pcs <- function(
 remove_missing_values <- function(
     tomic,
     value_var = NULL,
-    missing_val_method = "drop_samples") {
+    missing_val_method = "drop_samples",
+    verbose = TRUE
+    ) {
   checkmate::assertClass(tomic, "tomic")
   checkmate::assertChoice(
     missing_val_method,
     c("drop_features", "drop_samples")
   )
+  checkmate::assertLogical(verbose, len = 1)
 
   triple_omic <- tomic_to(tomic, "triple_omic")
 
@@ -170,7 +191,10 @@ remove_missing_values <- function(
       stop(missing_val_method, " is not an implemented missing value method")
     }
   } else {
-    message("No missing values found; returning input tomic")
+    if (verbose) {
+      message("No missing values found; returning input tomic")
+    }
+
     return(tomic)
   }
 
@@ -185,9 +209,11 @@ remove_missing_values <- function(
   n_dropped_samples <- n_initial_samples - nrow(triple_omic$samples)
 
   if (n_dropped_samples != 0) {
-    print(
-      glue::glue("{n_dropped_samples} samples dropped due to missing values")
-    )
+    if (verbose) {
+      print(
+        glue::glue("{n_dropped_samples} samples dropped due to missing values")
+      )
+    }
   }
 
   n_dropped_features <- observed_measurements %>%
@@ -196,9 +222,11 @@ remove_missing_values <- function(
     nrow()
 
   if (n_dropped_features != 0) {
-    print(
-      glue::glue("{n_dropped_features} features dropped due to missing values")
-    )
+    if (verbose) {
+      print(
+        glue::glue("{n_dropped_features} features dropped due to missing values")
+      )
+    }
   }
 
   return(tomic_to(triple_omic, class(tomic)[1]))
